/**
 * Click exit script.
 * <BR>Copyright (c) Nihilistic Software, Inc. 1998-1999
 *
 * Edited by Gordon Bergstrm (gordon.bergstrom@telia.com) : 07.19.2000
 * 
 * The changes is for removing some disciplines when changing scene. Like feral claws.
*/

public class ClickExit extends Codex
{
	private CodexThing	exitThing;
	private int			_exitNumber;

	private String		_locationName = "";

	private String		originalDescID = "";
	private boolean     bGotID = false;
	private String		ds_to_cancel[] = {"ef_disc_feralclaws", 
						   "ef_disc_cloakofshadows"};
	private int		size_of_ds     = 2;

	public static String _params[] = {"Exit number;0"};

	public ClickExit(int exitNumber)
	{
		exitThing = new CodexThing(GetClassThing());

		_exitNumber = exitNumber;
	}

	public void beginscene(int clientGuid, int captureID)
	{
		exitThing.SetThingFlags(THING_FLAG_NOSTDELETE);

		CodexThing playerThing = new CodexThing(clientGuid);
		CodexActor actor = new CodexActor(clientGuid);
		actor.SetStats(false);

		int locationNum = playerThing.GetLocationNum();
		_locationName = CodexSequence.GetLocationName(locationNum);

		if(!bGotID)
		{
			originalDescID = exitThing.GetDescriptionID();

			bGotID = true;
		}

		// check to see if the exit is valid - if not, set it to not highlight
		// if it is, make sure it's highlightable
		if(!CodexSequence.IsExitValid(_locationName, _exitNumber))
		{
			exitThing.SetThingFlags(THING_FLAG_NOHIGHLIGHT);
		}
		else
		{
			exitThing.ClearThingFlags(THING_FLAG_NOHIGHLIGHT);
		}

		// check to see if the exit is closed
		if(CodexSequence.IsExitClosed(_locationName, _exitNumber))
		{
			exitThing.SetDescriptionID(originalDescID + "_L");	
		}
		else
		{
			exitThing.SetDescriptionID(originalDescID);
		}
	}

	public void exitstatechanged()
	{
		// if we haven't gotten the original id, just get out, because none of this
		// will be valid
		if(!bGotID)
			return;

		// somewhere, sometime an exit has either been opened or closed so we re-check 
		// to see if this exit is closed and set the descriptionID accordingly
		if(CodexSequence.IsExitClosed(_locationName, _exitNumber))
		{
			exitThing.SetDescriptionID(originalDescID + "_L");	
		}
		else
		{
			exitThing.SetDescriptionID(originalDescID);
		}
	}

	public void clicked(int guid, int clickerGuid, int captureID)
	{
		// if we haven't gotten the original id, just get out, because none of this
		// will be valid
		if(!bGotID)
			return;

		// check to see if the exit is open
		if(!CodexSequence.IsExitClosed(_locationName, _exitNumber))
		{
			// if it's open, take it
			CodexSequence.TakeExit(_exitNumber, clickerGuid);

			// check to see if there is any active disciplines, in that case remove them
			CodexPlayer playerThing = new CodexPlayer(clickerGuid);

			for(int i=0; i< size_of_ds; i++) { 
				int effectGuid = playerThing.FindActorEffect(ds_to_cancel[i]);
				if(effectGuid != 0)
					playerThing.RemoveActorEffect(effectGuid);
			}
		}
		else
		{
			// sound indicating this exit is locked
			new CodexSound("locked_large_02.WAV", 300, 600, 100, 0, 0, clickerGuid);

			// display locked message
			CodexConsole.PrintNLS(clickerGuid, 0, "GEN_DOORLOCKED");
		}
	}

	public void save(int flags)
	{
		CodexSequence.SaveBoolean(bGotID);
		CodexSequence.SaveString(originalDescID);
		CodexSequence.SaveString(_locationName);
	}

	public void restore(int flags)
	{
		bGotID = CodexSequence.RestoreBoolean();
		originalDescID = CodexSequence.RestoreString();
		_locationName = CodexSequence.RestoreString();
	}

	public void stcommand(String blah, int locationIndex, float exitNum, float p1, float p2, float p3)
	{
		if(blah.equalsIgnoreCase("unlock"))
 		{
			String LocationName;
			if (locationIndex>=99)
				LocationName=_locationName;
			else
				LocationName=CodexSequence.GetLocationName(locationIndex);
			if (CodexSequence.IsExitClosed(LocationName, (int)exitNum))
			{
				CodexSequence.OpenExit(LocationName, (int)exitNum);
 				CodexConsole.Print(0, CONSOLEPRINT_FLAG_SERVERCONSOLE, "Unlocked: "+LocationName +" "+(int)exitNum, 0xFFFFFF);
			}
 		}
 		else if (blah.equalsIgnoreCase("lock"))
 		{
			String LocationName;
			if (locationIndex>=99)
				LocationName=_locationName;
			else
				LocationName=CodexSequence.GetLocationName(locationIndex);
			if (!CodexSequence.IsExitClosed(LocationName, (int)exitNum))
			{
				CodexSequence.CloseExit(LocationName, (int)exitNum);
 				CodexConsole.Print(0, CONSOLEPRINT_FLAG_SERVERCONSOLE, "Locked: "+LocationName+" "+(int)exitNum, 0xFFFFFF);
			}
		}
		
	}
	
	public void stcommand2(String blah)
	{
		CodexConsole.Print(0, CONSOLEPRINT_FLAG_SERVERCONSOLE, "Param: " + blah, 0xFFFFFF);	
	}

}
