/**
 * Codex Dice rolling class.
 * <BR>Copyright (c) Nihilistic Software, Inc. 1998-1999
 *
 * @author Spiritwolf (John Bellando)
*/


public class CodexDice extends Codex
{
       	protected	static final int	DIE_4_SIDES  	= 4;
       	protected	static final int	DIE_6_SIDES  	= 6;
       	protected	static final int	DIE_8_SIDES  	= 8;
       	protected	static final int	DIE_10_SIDES  	= 10;
       	protected	static final int	DIE_12_SIDES  	= 12;
       	protected	static final int	DIE_20_SIDES  	= 20;

	// --------------------------------------------------------------------------------------------

	public CodexDice()
	{
	}

	// Does a basic check for 1 success on a number of Die Rolls equal to
	//   Trait (0-200) + Skill (0-5) with a Difficulty between 1 and 10.
	// Parameters:
	//    traitValue - Float value of Trait (0-200)
	//    skillValue - Integer value of the Skill/Discipline (0-5)
        //    dieSides   - Integer value of the Number of Sides on the Die
	//    diffRating - Integer value of the Difficulty Rating (1-10)
	public static boolean SkillCheckSuccessful(float traitValue, int skillValue, int dieSides, int diffRating)
	{
		int numDice = Math.round(traitValue/20.0f) + skillValue;
		
		for (int rollCount = 1; rollCount <= numDice; rollCount++)
                {
                        if ( Math.floor((Math.random()) * dieSides + 1) >= diffRating )
                                return(true);
                }
		return(false);
	}
		
	// Checks for a specified number of successes on a number of Die Rolls equal to 
	//   Trait (0-200) + Skill (0-5) with a Difficulty between 1 and 10.
	// Parameters:
	//    traitValue - Float value of Trait (0-200)
	//    skillValue - Integer value of the Skill/Discipline (0-5)
        //    dieSides   - Integer value of the Number of Sides on the Die
	//    diffRating - Integer value of the Difficulty Rating (1-10)
        //    reqSuccess - Integer value of the Required Number of Successes (1-10)
	public static boolean SkillCheckMultiSuccessful(float traitValue, int skillValue, int dieSides, int diffRating, int reqSuccess)
	{
		int numDice = Math.round(traitValue/20.0f) + skillValue;
		int numSuccesses = 0;
                
		for (int rollCount = 1; rollCount <= numDice; rollCount++)
                {
                        if ( Math.floor((Math.random()) * dieSides + 1) >= diffRating )
                                numSuccesses++;
                }
		
                if (numSuccesses >= reqSuccess)
                        return(true);
                
                return(false);
	}

	// Returns the number of successes on a number of Die Rolls equal to 
	//   Trait (0-200) + Skill (0-5) with a Difficulty between 1 and 10.
	// Parameters:
	//    traitValue - Float value of Trait (0-200)
	//    skillValue - Integer value of the Skill/Discipline (0-5)
        //    dieSides   - Integer value of the Number of Sides on the Die
	//    diffRating - Integer value of the Difficulty Rating (1-10)
	public static int SkillCheckSuccesses(float traitValue, int skillValue, int dieSides, int diffRating)
	{
		int numDice = Math.round(traitValue/20.0f) + skillValue;
		int numSuccesses = 0;
                
		for (int rollCount = 1; rollCount <= numDice; rollCount++)
                {
                        if ( Math.floor((Math.random()) * dieSides + 1) >= diffRating )
                                numSuccesses++;
                }
		return(numSuccesses);
	}

}

