/**
 * Discipline Diablerize script.
 * <BR>Copyright (c) Nihilistic Software, Inc. 1998-1999
 *
 * @author YB
 *
 * A lot of credit to Damaramu (tyrus@soltec.net) who has quite a bit of code 
 * here and has given a whole lot of input.
 * Also credit to Chuck5, Zem, and Nihilistic Editing Board for other input. 
 * 
 * Modified by Nick Mossie (Lord Deviator : ld@initiated.com) : 07.04.2000 
 * to implement WoD correct Diablerie and correct stats via SetStats() 
 * from the CodexActor() type.
 * 
 * Lots and lots of specific input from Jack9 (jack9@earthlink.net). 
 * 
*/


public class DisciplineDiablerize extends Discipline
{
	private static final String	DISCIPLINE_NAME	= "Diablerize";
	private float			targetblood     = 999; 
	private float 			currentgen;		
	private float 			currenthum;		
	private float 			currentblood;		
	private boolean 		bkilledByDiab;
	
	// --------------------------------------------------------------------------------------------

	public DisciplineDiablerize()
	{
	}

	// --------------------------------------------------------------------------------------------

	public boolean cancast(int level, int casterGuid, int targetGuid, float x, float y, float z, boolean bIsPos)
	{
		if(!CheckCastParameters(level, casterGuid, DISCIPLINE_NAME))
			return(false);

		if(!CheckCastTarget(targetGuid, DISCIPLINE_NAME))
			return(false);

		// Check that the target can be fed on
		if((targetThing.GetActorFlags() & THING_AF_NOFEED) != 0)
			return(false);

		// If it's not a vampire, then you can't even attempt to
		// diablerize it.
		if(targetThing.GetActorType() != ACTOR_TYPE_VAMPIRE)
			return(false);
	
		return(true);
	}


	public int cast(int level, int casterGuid, int targetGuid)
	{
		// do sanity checks
		if(!CheckCastParameters(level, casterGuid, DISCIPLINE_NAME))
			return(0);

		if(!CheckCastTarget(targetGuid, DISCIPLINE_NAME))
			return(0);

		SetupWorld(DISCIPLINE_NAME);

		CaptureThing(casterGuid,0);
		CaptureThing(targetGuid,1);

		try
		{
			casterThing.Feed(targetGuid);
			return(1);
		}
		catch(Exception e)
		{
			CodexConsole.PrintException(e.getMessage() + " in " + DISCIPLINE_NAME + " [cast]");
			return(0);
		}
		catch(Error e)
		{
			CodexConsole.PrintError(e.getMessage() + " in " + DISCIPLINE_NAME + " [cast]");
			return(0);
		}
	}

	public void actorfeed(int actorGUID, int targetGUID, int status, int captureID) 
	{
	
		int	myclan;

		if(captureID !=0)
			return;

		
		if(status == ACTORFEED_STATUS_INPROGRESS || 
		   status == ACTORFEED_STATUS_START) 
		{
			targetblood=targetThing.GetActorStat(ACTOR_STAT_BLOOD);
			currentblood=casterThing.GetActorStat(ACTOR_STAT_BLOOD);
			currenthum = casterThing.GetActorStat(ACTOR_STAT_HUMANITY);
			if(casterThing.GetActorType()==ACTOR_TYPE_VAMPIRE)
				currentgen=casterThing.GetActorStat(ACTOR_STAT_GENERATION);
		}
	
		if(status == ACTORFEED_STATUS_INPROGRESS && 
		   targetThing.GetActorType() == ACTOR_TYPE_VAMPIRE && 
		   casterThing.GetActorType() == ACTOR_TYPE_VAMPIRE) 
		{

			if(targetblood < 6) 
			{
				CodexConsole.Print(actorGUID, 0, casterThing.GetName() + "!  Stop now or you will diablerize your prey!");
			}
			else if(targetblood < 8) 
			{
				CodexConsole.Print(actorGUID, 0, casterThing.GetName() + " is VERY close to diablerizing the victim.");
			}
			else if(targetblood < 13) 
			{
				CodexConsole.Print(actorGUID, 0, casterThing.GetName() + " is getting close to diablerizing the victim.");
			}
		}
			
 	  	if(status == ACTORFEED_STATUS_STOPKILLED && 
		   bkilledByDiab == true) 
		{
			// Target vampire has died and was actually killed by 
			// the vampire attacker that initiated the feed.
			// It is a diablerie and not just a death on an
			// aborted attempt.

			CodexConsole.Print(actorGUID, 0, casterThing.GetName() + " has diablerized " + targetThing.GetName() + ".");

			ReleaseThing(actorGUID);

			// Lower Humanity
			// 
			// New!  Don't lower humanity of non Camarilla  
			// clans 
			myclan=casterThing.GetActorClanId();
			if((myclan == ACTOR_CLAN_USERDEFINED) ||
			   (myclan == ACTOR_CLAN_TZIMISCE) ||	
			   (myclan == ACTOR_CLAN_RAVNOS) ||	
			   (myclan == ACTOR_CLAN_LASOMBRA) ||	
			   (myclan == ACTOR_CLAN_GIOVANNI) ||	
			   (myclan == ACTOR_CLAN_CAPPADOCIAN) ||	
		   	   (myclan == ACTOR_CLAN_SETITE) ||	
			   (myclan == ACTOR_CLAN_ASSAMITE)) 
			{   
   				casterThing.SetActorStat(ACTOR_STAT_HUMANITY, (currenthum));	
				// This effectively does nothing but we need
				// something here.
			}
			else 
			{
				casterThing.AddActorEffectByLevel("ef_decreasehumanity", 0, 3, actorGUID, EI_FLAG_DISCIPLINE);
			}	

			//Set Aura to Diablerist
			casterThing.SetActorAura("Diablerist");

			if(targetThing.GetActorStat(ACTOR_STAT_GENERATION) < casterThing.GetActorStat(ACTOR_STAT_GENERATION)) 
			{

			   	// Lower Generation
				// If diablerie gen is twice or more then the	
				// diablerist, then the diablerist goes down 2.

				if((targetThing.GetActorStat(ACTOR_STAT_GENERATION)*2) <= casterThing.GetActorStat(ACTOR_STAT_GENERATION)) 
				{ 
					casterThing.AddActorEffectByLevel("ef_lowergeneration", 0, 1, actorGUID, EI_FLAG_DISCIPLINE);
					CodexConsole.Print(actorGUID, 0, casterThing.GetName() + " has gone down 2 generations.");
				}
				else 
				{
					casterThing.AddActorEffectByLevel("ef_lowergeneration", 0, 0, actorGUID, EI_FLAG_DISCIPLINE);
					CodexConsole.Print(actorGUID, 0, casterThing.GetName() + " has gone down 1 generation.");
				}
				
				// Set blood pool and health
				casterThing.SetStats(false);
				targetThing.Remove();
			}
 	  	} 
		else if(status == ACTORFEED_STATUS_STOPKILLED) 
		{ 

			// This is keep draining and killing mortals from 
			// resetting your gen to 13 and thus making your 
			// stats go back down as well.
			//
			// Added humanity resetter.  This captures lowering
			// humanity on mortals.  NOW we can implement paths
			// by not lower humanity of sabbat clans!

			ReleaseThing(targetGUID);
			ReleaseThing(actorGUID);
			if(casterThing.GetActorType()==ACTOR_TYPE_VAMPIRE) 
			{
				casterThing.SetActorStat(ACTOR_STAT_GENERATION, currentgen);
				myclan=casterThing.GetActorClanId();
				if((myclan == ACTOR_CLAN_USERDEFINED) ||
				   (myclan == ACTOR_CLAN_TZIMISCE) ||	
				   (myclan == ACTOR_CLAN_RAVNOS) ||	
				   (myclan == ACTOR_CLAN_LASOMBRA) ||	
				   (myclan == ACTOR_CLAN_GIOVANNI) ||	
			   	   (myclan == ACTOR_CLAN_CAPPADOCIAN) ||	
			   	   (myclan == ACTOR_CLAN_SETITE) ||	
				   (myclan == ACTOR_CLAN_ASSAMITE)) 
				{   
					// This doesn't work like the diablerie
					// one.  It always takes off the 5
					// humanity for killing the mortal.
					// So we'll add it back.
					casterThing.AddActorEffectByLevel("ef_increasehumanity", 0, 0, actorGUID, EI_FLAG_DISCIPLINE);

					// This just corrupts it here for 
					// some reason.
					//casterThing.SetActorStat(ACTOR_STAT_HUMANITY, (currenthum));
				}	
//				else
//					casterThing.AddActorEffectByLevel("ef_decreasehumanity", 0, 0, actorGUID, EI_FLAG_DISCIPLINE);
				
			}	
			casterThing.SetStats(false);
		}
	}	

	public void killed(int guid, int causeGUID, int captureID) 
	{
		
		if(captureID != 1)
			return;

		// Determine if this was a diablerie. 
		// First the causeGUID really the killer? 
		// Then are the things both vampires?
		// Then is the target blood pool less then 5?
		// If all that is true, then it was a diablerie, otherwise it
		// is not.
		// The special case is the innermost one... if the person did
		// actually die and both things were vampires and the thing
		// was actually killed by the correct caster, then they should
		// be revived with minimal stats because they are not toast.

		if(causeGUID == casterThing.GetGUID()) 
		{
			if(casterThing.GetActorType()==ACTOR_TYPE_VAMPIRE &&
			   targetThing.GetActorType()==ACTOR_TYPE_VAMPIRE)  
			{					
				if(targetblood<5) 
				{
					bkilledByDiab=true;
					// Release the Dead thing
					ReleaseThing(guid);
				}	
				else 
				{
					bkilledByDiab=false;
					targetThing.ReviveActor((float).01,(float).01);
					targetThing.SetStats(false);
					targetThing.SetActorHealth(4);
				}
			}
			else 
			{
				bkilledByDiab=false;
				// Release the Dead thing
				ReleaseThing(guid);
			}
		}
		else 
		{
			bkilledByDiab=false;
			// Release the Dead thing
			ReleaseThing(guid);
		}

	}
}

