/**
 * Discipline Embrace script.
 * <BR>Copyright (c) Nihilistic Software, Inc. 1998-1999
 *
 * @author YB
 * mod Spock
*/


public class DisciplineEmbrace extends Discipline
{
  	private static final String	DISCIPLINE_NAME	= "Embrace";

	// --------------------------------------------------------------------------------------------

	public DisciplineEmbrace()
	{
	}

	// --------------------------------------------------------------------------------------------

	public boolean cancast(int level, int casterGuid, int targetGuid, float x, float y, float z, boolean bIsPos)
	{


    if(!CheckCastParameters(level, casterGuid, DISCIPLINE_NAME))
			return(false);

		if(!CheckCastTarget(targetGuid, DISCIPLINE_NAME))
			return(false);

		// Check that the target can be fed on
		if((targetThing.GetActorFlags() & THING_AF_NOFEED) != 0)
			return(false);

    //Set target to not be on your team so you can embrace them
    targetThing.SetActorTeam(TEAM_NONE);

		// ghouls can only wristfeed from vampires in their team
		if((casterThing.GetActorType() == ACTOR_TYPE_GHOUL) &&
      ((targetThing.GetActorType() != ACTOR_TYPE_VAMPIRE) ||
       (casterThing.GetActorTeam() != targetThing.GetActorTeam())))
			return(false);

    //can't embrace a vampire
    if(targetThing.GetActorType() == ACTOR_TYPE_VAMPIRE)
      return(false);

		return(true);
	}

	public int cast(int level, int casterGuid, int targetGuid)
	{
		// do sanity checks
		if(!CheckCastParameters(level, casterGuid, DISCIPLINE_NAME))
			return(0);

		if(!CheckCastTarget(targetGuid, DISCIPLINE_NAME))
			return(0);

		SetupWorld(DISCIPLINE_NAME);



		CaptureThing(casterGuid);

		try
		{
			casterThing.Feed(targetGuid);
			return(1);
		}
		catch(Exception e)
		{
			CodexConsole.PrintException(e.getMessage() + " in " + DISCIPLINE_NAME + " [cast]");
			return(0);
		}
		catch(Error e)
		{
			CodexConsole.PrintError(e.getMessage() + " in " + DISCIPLINE_NAME + " [cast]");
			return(0);
		}
	}

	public void actorfeed(int actorGUID, int targetGUID, int status, int captureID)
	{
		//ACTORFEED_STATUS_STOPKILLED
		if (status == ACTORFEED_STATUS_INPROGRESS
        && casterThing.GetActorType() == ACTOR_TYPE_VAMPIRE)
		{
            //Added for embrace
      if ((targetThing.GetActorType() == ACTOR_TYPE_HUMAN ||
          targetThing.GetActorType() == ACTOR_TYPE_GHOUL) &&
          targetThing.GetActorStat(ACTOR_STAT_BLOOD) <= 10 ) //Embrace
			{
			  targetThing.SetActorType(ACTOR_TYPE_VAMPIRE);
			  targetThing.AddActorEffectByLevel("ef_decreasefrenzy",0,0,0,0);
			  targetThing.SetActorStat(ACTOR_STAT_GENERATION,casterThing.GetActorStat(ACTOR_STAT_GENERATION) + 1);
	      // Set common disciplines
        targetThing.SetActorDisciplineLevel("Feed",0);
        targetThing.SetActorDisciplineLevel("BloodHealing",0);
        targetThing.SetActorDisciplineLevel("BloodStrength",0);
	      targetThing.SetActorDisciplineLevel("BloodDexterity",0);
	      targetThing.SetActorDisciplineLevel("BloodStamina",0);
	      targetThing.SetActorDisciplineLevel("Ghoulize",0);
	      if(targetThing.GetActorStat(ACTOR_STAT_GENERATION) < 13)
        	targetThing.SetActorDisciplineLevel("Embrace",0);
      	if(targetThing.GetActorStat(ACTOR_STAT_GENERATION) < 7)
        	targetThing.SetActorDisciplineLevel("Awaken",0);
			  targetThing.SetActorClan(casterThing.GetActorClan());
        targetThing.SetActorAura("Vampire");
			  targetThing.SetActorBaseStat(ACTOR_STAT_FAITH, 20);
			  targetThing.SetActorStat(ACTOR_STAT_FAITH, 20);
			  targetThing.SetActorBaseStat(ACTOR_STAT_FRENZYRATING, 50);
			  targetThing.SetActorStat(ACTOR_STAT_FRENZYRATING, 50);
			  targetThing.SetActorBaseStat(ACTOR_STAT_FRENZY, 50);
			  targetThing.SetActorStat(ACTOR_STAT_FRENZY, 50);
			  targetThing.SetActorBaseStat(ACTOR_STAT_MANA, 0);
			  targetThing.SetActorStat(ACTOR_STAT_MANA, 0);
			  targetThing.SetActorBaseStat(ACTOR_STAT_MANAPOOL, 0);
			  targetThing.SetActorStat(ACTOR_STAT_MANAPOOL, 0);
			  targetThing.SetActorTeam(casterThing.GetActorTeam());
			  CodexConsole.PrintNLS(targetGUID, 0, "You have become a child of Caine");
        casterThing.SetActorStat(ACTOR_STAT_BLOOD,casterThing.GetActorStat(ACTOR_STAT_BLOOD) - 30);
        targetThing.SetActorStat(ACTOR_STAT_BLOOD,targetThing.GetActorStat(ACTOR_STAT_BLOOD) + 30);
      	casterThing.SetStats(false);
        //Add base clan disciplines at 0
        switch (casterThing.GetActorClanId())
        {
           case ACTOR_CLAN_NOSFERATU:
             targetThing.SetActorDisciplineLevel("CloakofShadows",0);
             targetThing.SetActorDisciplineLevel("Potence",0);
             targetThing.SetActorDisciplineLevel("FeralWhispers",0);
             targetThing.SetActorStat(ACTOR_STAT_APPEARANCE, 0);
             targetThing.SetActorBaseStat(ACTOR_STAT_APPEARANCE, 0);
             break;
           case ACTOR_CLAN_BRUJAH:
             targetThing.SetActorDisciplineLevel("Celerity",0);
             targetThing.SetActorDisciplineLevel("Potence",0);
             targetThing.SetActorDisciplineLevel("Awe",0);
             break;
           case ACTOR_CLAN_CAPPADOCIAN:
             targetThing.SetActorDisciplineLevel("HeightenedSenses",0);
             targetThing.SetActorDisciplineLevel("Fortitude",0);
             targetThing.SetActorDisciplineLevel("ShamblingHordes",0);
             break;
           case ACTOR_CLAN_GANGREL:
             targetThing.SetActorDisciplineLevel("FeralWhispers",0);
             targetThing.SetActorDisciplineLevel("Fortitude",0);
             targetThing.SetActorDisciplineLevel("EyesOfTheBeast",0);
             break;
           case ACTOR_CLAN_TOREADOR:
             targetThing.SetActorDisciplineLevel("Celerity",0);
             targetThing.SetActorDisciplineLevel("HeightenedSenses",0);
             targetThing.SetActorDisciplineLevel("Awe",0);
             break;
           case ACTOR_CLAN_GIOVANNI:
             targetThing.SetActorDisciplineLevel("Command",0);
             targetThing.SetActorDisciplineLevel("Potence",0);
             targetThing.SetActorDisciplineLevel("ShamblingHordes",0);
             break;
           case ACTOR_CLAN_LASOMBRA:
             targetThing.SetActorDisciplineLevel("Command",0);
             targetThing.SetActorDisciplineLevel("Potence",0);
             targetThing.SetActorDisciplineLevel("DarkHunter",0);
             break;
           case ACTOR_CLAN_MALKAVIAN:
             targetThing.SetActorDisciplineLevel("HeightenedSenses",0);
             targetThing.SetActorDisciplineLevel("Passion",0);
             targetThing.SetActorDisciplineLevel("CloakofShadows",0);
             break;
           case ACTOR_CLAN_SETITE:
             targetThing.SetActorDisciplineLevel("CloakofShadows",0);
             targetThing.SetActorDisciplineLevel("EyesOfTheSerpent",0);
             targetThing.SetActorDisciplineLevel("Awe",0);
             break;
           case ACTOR_CLAN_TREMERE:
             targetThing.SetActorDisciplineLevel("Command",0);
             targetThing.SetActorDisciplineLevel("BloodRage",0);
             targetThing.SetActorDisciplineLevel("HeightenedSenses",0);
             break;
           case ACTOR_CLAN_VENTRUE:
             targetThing.SetActorDisciplineLevel("Command",0);
             targetThing.SetActorDisciplineLevel("Fortitude",0);
             targetThing.SetActorDisciplineLevel("Awe",0);
             break;

           default:
           break;
        }
        casterThing.StopFeeding();
			}
		}
	}

}

